@@ -7,7 +7,8 @@ price = []
 def init(app: Flask):
   app.template_folder = Path(__file__).parent.absolute()
 
-  print("Template >>>" + Path(__file__).parent.absolute())
+  print("Template >>>")
+  print(Path(__file__).parent.absolute())
 
   @app.route('/price', methods=['POST'])
   def set_price():
